@@ -89,6 +89,7 @@ use G::Tools::KEGG_API;
 use G::Tools::KEGG_API3;
 use G::Tools::RCluster;
 use G::Tools::PEC;
+use G::Tools::Statistics;
 use G::SystemsBiology::Serizawa;
 use G::SystemsBiology::Pathway;
 use G::SystemsBiology::PathwayAlignment;
@@ -153,6 +154,7 @@ push(@EXPORT, @G::Tools::KEGG_API::EXPORT);
 push(@EXPORT, @G::Tools::KEGG_API3::EXPORT);
 push(@EXPORT, @G::Tools::RCluster::EXPORT);
 push(@EXPORT, @G::Tools::PEC::EXPORT);
+push(@EXPORT, @G::Tools::Statistics::EXPORT);
 push(@EXPORT, @G::SystemsBiology::Serizawa::EXPORT);
 push(@EXPORT, @G::SystemsBiology::Pathway::EXPORT);
 push(@EXPORT, @G::SystemsBiology::PathwayAlignment::EXPORT);
