@@ -177,7 +177,7 @@ sub help{
 sub process_g{
     next unless(/\.pm$/);
 
-    open(FILE, $File::Find::name) || die($!);
+    open(FILE, $File::Find::name) || die($File::Find::name, " ", $!);
     while(<FILE>){
 	chomp;
 	if(/\=head2\s+(.*)\s*$/){
@@ -197,7 +197,7 @@ sub process_g{
 sub process_bp{
     my $class = 'Bio';
 
-    if ($File::Find::name =~ /\/(Bio.*)\.pm/){
+    if ($File::Find::name =~ /\/(Bio.*)\.pm$/){
 	$class = $1;
 	$class =~ s/\//::/g;
     }else{
