@@ -32,14 +32,11 @@
 package Rcmd;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION);
 
 require Exporter;
 
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
-);
-$VERSION = '1.0';
+$VERSION = '1.01';
 
 srand(time ^ $$ ^ unpack "%L*", `ps axww | gzip`);
 
